@@ -1,7 +1,12 @@
+# Python to R
+import rpy2.robjects as robjects
+from rpy2.robjects.packages import importr
+import os
+
 def extract(dir, cdf = "hgu133plus2cdf"):
     affy = importr('affy')
     annotation = importr(cdf)
-    print("Annotation is using {}".format(ann))
+    print("Annotation is using {}".format(annotation))
 
     os.chdir(dir)
     datapath = os.getcwd()
@@ -20,17 +25,3 @@ def extract(dir, cdf = "hgu133plus2cdf"):
     print("This Platform have {} probes".format(df_len))
 
     return df, df_len
-
-def transform(df, df_len):
-    pandas2ri.activate()
-    r.data('df')
-    pandas_df = df.head(df_len)
-
-    col_name = pandas_df.columns.to_list()
-    col_name.insert(0, "ID")
-    Inputid = pandas_df.index
-    pandas_df.reindex(columns=col_name)
-    pandas_df["ID"] = Inputid
-    pandas_df = pandas_df.reindex(columns=col_name)
-
-    return pandas_df
