@@ -1,3 +1,6 @@
+# Python to R
+from rpy2.robjects import r, pandas2ri
+
 def transform(df, df_len):
     pandas2ri.activate()
     r.data('df')
